<!DOCTYPE html>
<html>
<head>
  [%- SET 
    File = c.stash.RapiFsFile 
    code = c.stash.code 
    pfx  = c.mount_url
  -%]
  
  <link href="[% pfx %]/assets/local/misc/static/prism.css" rel="stylesheet" />
  
  <style>
    pre, code {
      max-height: none !important;
      overflow: visible !important;
    }
  </style>
  
</head>

<body>

<pre class="line-numbers">
<code class="language-[% File.code_language %] line-numbers">
[%- code -%]
</code>
</pre>

  <script src="[% pfx %]/assets/local/misc/static/prism.js"></script>
</body>
</html>